@@ -83,6 +83,7 @@ BEGIN_RCPP
     imat S(nkeep,np);
     field<icolvec> Num(nkeep,1);
     field<ucolvec> bigS;
+    field<mat> optPartition(3,1); /* Hold empirical probability of co-clustering matrix, index of L-sq clustering scores objects, and cluster identifiers per iteration */
 
     // Initialize parameter values
     /* cluster capture variables */
@@ -99,6 +100,7 @@ BEGIN_RCPP
     colvec zb(nc); zb.zeros();
     double conc = 1; /* DP concentration parameter */
     ucolvec ordscore; ordscore.zeros(); /* LS score order */
+    mat phat(np,np); phat.zeros(); /* empirical co-clustering probability matrix */
     /* remaining parameter set */
     colvec beta = randn<colvec>(nf)*sqrt(1/taubeta);
     colvec eta(ng); eta.zeros(); /* group means of session effects */
@@ -174,7 +176,10 @@ BEGIN_RCPP
     } /* end MCMC loop over k */
 
     // compute least squares cluster
-    lsqcluster(S, Num, ordscore, bigS);
+    lsqcluster(S, Num, ordscore, phat, bigS);
+    optPartition(0,0) = phat;
+    optPartition(1,0) = conv_to<mat>::from(ordscore);
+    optPartition(2,0) = conv_to<mat>::from(S);
     // DIC
     dic3comp(Deviance, Devmarg, devres); /* devres = c(dic,dbar,dhat,pd) */
     cpo(Devmarg, logcpo, lpml);
@@ -197,9 +202,9 @@ BEGIN_RCPP
                                   Rcpp::Named("Taub") = Taub,
                                   Rcpp::Named("Residuals") = Resid,
                                   Rcpp::Named("M") = numM,
-                                  Rcpp::Named("S") = S,
+                                  //Rcpp::Named("S") = S,
                                   Rcpp::Named("Num") = Num,
-                                  //Rcpp::Named("ordscore") = ordscore,
+                                  Rcpp::Named("optPartition") = optPartition,
                                   Rcpp::Named("bigSmin") = bigS
                                   );
 
